# gtFrame
```gtFrame``` is a lightweigt python package for working with frames of reference in classical mechanics simulations.

## Installation

To install ```gtFrame``` simply use pip:
```pip install gtFrame```

## Documentation

Link to the [docs](https://gtframe.readthedocs.io/en/stable/).
